//
//  ExampleController.m
//  Example Application
//
//  Created by Jan Christiansen on 9/12/12.
//  Copyright (c) 2012, Monoid - Development and Consulting - Jan Christiansen
//
//  All rights reserved.
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions are met:
//
//  * Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//  * Redistributions in binary form must reproduce the above
//  copyright notice, this list of conditions and the following
//  disclaimer in the documentation and/or other materials provided
//  with the distribution.
//
//  * Neither the name of Monoid - Development and Consulting -
//  Jan Christiansen nor the names of other
//  contributors may be used to endorse or promote products derived
//  from this software without specific prior written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
//  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
//  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
//  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
//  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#import "ExampleController.h"


@implementation ExampleController {

    NSArray *_shadowPositions;
}


- (void)viewDidLoad {

    [super viewDidLoad];

    self.tableView.shadowPositions = MOBackgroundOriginShadow | MOBackgroundBottomShadow | MOTableOriginShadow | MOTableBottomShadow;
    self.tableView.backgroundColor = [UIColor darkGrayColor];

    self.title = @"MOShadowTableView";

    _shadowPositions =
      @[@"Background Origin Shadow",
        @"Background Bottom Shadow",
        @"Table Origin Shadow",
        @"Table Bottom Shadow",
        @"All Shadows",
        @"",
        @"",
        @"",
        @"",
        @"",
        @""];
}


#pragma mark - UITableViewDataSource Methods

- (NSInteger)numberOfSectionsInTableView:(UITableView *)__unused tableView {

    return 1;
}

- (NSInteger)tableView:(UITableView *)__unused tableView
 numberOfRowsInSection:(NSInteger)__unused section {

    return (NSInteger) _shadowPositions.count;
}

- (UITableViewCell *)tableView:(UITableView *)__unused tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath {

    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];

    if (!cell) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle
                                      reuseIdentifier:CellIdentifier];
    }
    cell.textLabel.text = [_shadowPositions objectAtIndex:indexPath.row];
    cell.contentView.backgroundColor = [UIColor whiteColor];
    cell.selectionStyle = UITableViewCellSelectionStyleNone;

    return cell;
}


#pragma mark - UITableViewDelegate Methods

- (void)tableView:(UITableView *)__unused tableView
didSelectRowAtIndexPath:(NSIndexPath *)indexPath {

    switch (indexPath.row) {
        case 0:
            self.tableView.shadowPositions = MOBackgroundOriginShadow;
            break;

        case 1:
            self.tableView.shadowPositions = MOBackgroundBottomShadow;
            break;

        case 2:
            self.tableView.shadowPositions = MOTableOriginShadow;
            break;

        case 3:
            self.tableView.shadowPositions = MOTableBottomShadow;
            break;

        case 4:
            self.tableView.shadowPositions = MOBackgroundOriginShadow
                                           | MOBackgroundBottomShadow
                                           | MOTableOriginShadow
                                           | MOTableBottomShadow;
            break;
    }
}

@end
