//
//  UIView+MOShadow.h
//  MOShadowTableView
//
//  Created by Jan Christiansen on 9/12/12.
//  Copyright (c) 2012, Monoid - Development and Consulting - Jan Christiansen
//
//  All rights reserved.
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions are met:
//
//  * Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//  * Redistributions in binary form must reproduce the above
//  copyright notice, this list of conditions and the following
//  disclaimer in the documentation and/or other materials provided
//  with the distribution.
//
//  * Neither the name of Monoid - Development and Consulting -
//  Jan Christiansen nor the names of other
//  contributors may be used to endorse or promote products derived
//  from this software without specific prior written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
//  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
//  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
//  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
//  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#import <UIKit/UIKit.h>
#import <QuartzCore/QuartzCore.h>


/**
 * Category to add a shadow to the top or the bottom and outside or insde
 * a UIView
 */
@interface UIView (MOShadow)


typedef NS_ENUM(NSUInteger, MOViewShadowStyle) {
    MOViewShadowTopInside,
    MOViewShadowTopOutside,
    MOViewShadowBottomInside,
    MOViewShadowBottomOutside
};


/**
 * Add a shadow to the view.
 * @param style determines the position of the layer w.r.t. the view
 */
- (CAGradientLayer *)addShadowWithStyle:(MOViewShadowStyle)style
                                 height:(CGFloat)height
                                  alpha:(CGFloat)alpha;

/**
 * Add a shadow to the view.
 * @param style determines the position of the layer w.r.t. the view
 * @param inset inset between view bounds and shadow
 */
- (CAGradientLayer *)addShadowWithStyle:(MOViewShadowStyle)style
                                 height:(CGFloat)height
                                  alpha:(CGFloat)alpha
                                  inset:(UIEdgeInsets)inset;


@end
