//
//  UIView+MOShadow.m
//  MOShadowTableView
//
//  Created by Jan Christiansen on 9/12/12.
//  Copyright (c) 2012, Monoid - Development and Consulting - Jan Christiansen
//
//  All rights reserved.
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions are met:
//
//  * Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//  * Redistributions in binary form must reproduce the above
//  copyright notice, this list of conditions and the following
//  disclaimer in the documentation and/or other materials provided
//  with the distribution.
//
//  * Neither the name of Monoid - Development and Consulting -
//  Jan Christiansen nor the names of other
//  contributors may be used to endorse or promote products derived
//  from this software without specific prior written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
//  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
//  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
//  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
//  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#import "UIView+MOShadow.h"
#import <QuartzCore/QuartzCore.h>


@implementation UIView (MOShadow)


- (CAGradientLayer *)addShadowWithStyle:(MOViewShadowStyle)style
                                 height:(CGFloat)height
                                  alpha:(CGFloat)alpha {

    return [self addShadowWithStyle:style
                             height:height
                              alpha:alpha
                              inset:UIEdgeInsetsZero];
}

- (CAGradientLayer *)addShadowWithStyle:(MOViewShadowStyle)style
                                 height:(CGFloat)height
                                  alpha:(CGFloat)alpha
                                  inset:(UIEdgeInsets)inset {

    BOOL invertedShadow = style == MOViewShadowTopOutside || style == MOViewShadowBottomInside;
    CAGradientLayer *shadow = [self shadowWithHeight:height
                                               alpha:alpha
                                            inverted:invertedShadow];
    [self.layer insertSublayer:shadow atIndex:0];

    CGRect shadowFrame = shadow.frame;
    shadowFrame.size.width = self.layer.bounds.size.width;

    switch (style) {
        case MOViewShadowTopOutside:
            shadowFrame.origin.y = self.layer.bounds.origin.y - height + inset.top;
            break;
        case MOViewShadowTopInside:
            shadowFrame.origin.y = self.layer.bounds.origin.y + inset.top;
            break;
        case MOViewShadowBottomInside:
            shadowFrame.origin.y = self.layer.bounds.origin.y + self.layer.bounds.size.height - height - inset.bottom;
            break;
        case MOViewShadowBottomOutside:
            shadowFrame.origin.y = self.layer.bounds.origin.y + self.layer.bounds.size.height - inset.bottom;
            break;
    }

    shadow.frame = shadowFrame;
    return shadow;
}

// build a gradientlayer that displays a shadow
- (CAGradientLayer *)shadowWithHeight:(CGFloat)height
                                alpha:(CGFloat)alpha
                             inverted:(BOOL)inverted {

    CAGradientLayer *shadow = [[CAGradientLayer alloc] init];
    shadow.frame = CGRectMake(0,
                              0,
                              self.frame.size.width,
                              height);
    shadow.colors = @[(id)[[UIColor blackColor] colorWithAlphaComponent:alpha].CGColor,
                      (id)[[UIColor blackColor] colorWithAlphaComponent:0.5*alpha].CGColor,
                      (id)[[UIColor blackColor] colorWithAlphaComponent:0.25*alpha].CGColor,
                      (id)[UIColor clearColor].CGColor];
    if (inverted) {
        shadow.startPoint = CGPointMake(0.5, 1.0);
        shadow.endPoint = CGPointMake(0.5, 0.0);
    }

    return shadow;
}


@end
